// const w = window.innerWidth;
// const h = window.innerHeight;
const w = 800;
const h = 350;

const margin = { top: 40, right: 40, bottom: 40, left: 40 };

const colors = d3.scaleOrdinal(d3.schemeCategory10);

const parseTime = d3.timeParse('%Y-%m');

const formatTime = d3.timeFormat('%b %Y');

const dataPath = [
  'https://raw.githubusercontent.com/',
  'scotthmurray/d3-book/master/',
  'chapter_13/',
  'ev_sales_data.csv',
].join('');

const rowConverter = (d, i, cols) => {
  const row = { date: parseTime(d.Date) };

  for (let i = 1; i < cols.length; i++) {
    const col = cols[i];

    if (d[cols[i]]) {
      row[cols[i]] = +d[cols[i]];
    } else {
      row[cols[i]] = 0;
    }
  }

  return row;
};

const stack = d3.stack().order(d3.stackOrderDescending);

const plot = async () => {
  const data = await d3.csv(dataPath, rowConverter);

  const keys = data.columns;
  keys.shift();

  stack.keys(keys);

  const series = stack(data);

  const xScale = d3
    .scaleTime()
    .domain(d3.extent(data, (d) => d.date))
    .range([margin.left, w - margin.right]);

  const yScale = d3
    .scaleLinear()
    .domain([
      0,
      d3.max(data, (d) => {
        let sum = 0;

        for (let i = 0; i < keys.length; i++) {
          sum += d[keys[i]];
        }

        return sum;
      }),
    ])
    .range([h - margin.top, margin.bottom])
    .nice();

  console.log(yScale.range());

  const xAxis = d3
    .axisBottom()
    .scale(xScale)
    .ticks(10)
    .tickFormat(formatTime);

  const yAxis = d3.axisRight().scale(yScale).ticks(5);

  const area = d3
    .area()
    .x((d) => xScale(d.data.date))
    .y0((d) => yScale(d[0]))
    .y1((d) => yScale(d[1]));

  const svg = d3
    .select('body')
    .append('svg')
    .attr('width', w)
    .attr('height', h);

  svg
    .selectAll('path')
    .data(series)
    .join('path')
    .attr('class', 'area')
    .attr('d', area)
    .attr('fill', (d, i) => d3.schemeCategory10[i])
    .append('title')
    .text((d) => d.key);

  svg
    .append('g')
    .attr('class', 'axis')
    .attr(
      'transform',
      `translate(0, ${h - margin.bottom / 1.2})`
    )
    .call(xAxis);
  
    svg
    .append('g')
    .attr('class', 'axis')
    .attr(
      'transform',
      `translate(${w - margin.right / 1.2}, 0)`
    )
    .call(yAxis);
};

plot();
